// <copyright file="AsyncLocalRuntimeContextSlot.cs" company="OpenTelemetry Authors">
// Copyright The OpenTelemetry Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
// </copyright>

using System.Runtime.CompilerServices;
using System.Threading;

namespace OpenTelemetry.Context
{
    /// <summary>
    /// The async local implementation of context slot.
    /// </summary>
    /// <typeparam name="T">The type of the underlying value.</typeparam>
    public class AsyncLocalRuntimeContextSlot<T> : RuntimeContextSlot<T>, IRuntimeContextSlotValueAccessor
    {
        private readonly AsyncLocal<T> slot;

        /// <summary>
        /// Initializes a new instance of the <see cref="AsyncLocalRuntimeContextSlot{T}"/> class.
        /// </summary>
        /// <param name="name">The name of the context slot.</param>
        public AsyncLocalRuntimeContextSlot(string name)
            : base(name)
        {
            this.slot = new AsyncLocal<T>();
        }

        /// <inheritdoc/>
        public object Value
        {
            get => this.slot.Value;
            set => this.slot.Value = (T)value;
        }

        /// <inheritdoc/>
        [MethodImpl(MethodImplOptions.AggressiveInlining)]
        public override T Get()
        {
            return this.slot.Value;
        }

        /// <inheritdoc/>
        [MethodImpl(MethodImplOptions.AggressiveInlining)]
        public override void Set(T value)
        {
            this.slot.Value = value;
        }
    }
}
