// <copyright file="PrometheusExporterOptions.cs" company="OpenTelemetry Authors">
// Copyright The OpenTelemetry Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
// </copyright>

using OpenTelemetry.Internal;

namespace OpenTelemetry.Exporter.Prometheus
{
    /// <summary>
    /// Prometheus exporter options.
    /// </summary>
    internal sealed class PrometheusExporterOptions
    {
        private int scrapeResponseCacheDurationMilliseconds = 300;

        /// <summary>
        /// Gets or sets the cache duration in milliseconds for scrape responses. Default value: 300.
        /// </summary>
        /// <remarks>
        /// Note: Specify 0 to disable response caching.
        /// </remarks>
        public int ScrapeResponseCacheDurationMilliseconds
        {
            get => this.scrapeResponseCacheDurationMilliseconds;
            set
            {
                Guard.ThrowIfOutOfRange(value, min: 0);

                this.scrapeResponseCacheDurationMilliseconds = value;
            }
        }
    }
}
