// <copyright file="HistogramBucket.cs" company="OpenTelemetry Authors">
// Copyright The OpenTelemetry Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
// </copyright>

namespace OpenTelemetry.Metrics
{
    /// <summary>
    /// Represents a bucket in the histogram metric type.
    /// </summary>
    public readonly struct HistogramBucket
    {
        internal HistogramBucket(double explicitBound, long bucketCount)
        {
            this.ExplicitBound = explicitBound;
            this.BucketCount = bucketCount;
        }

        /// <summary>
        /// Gets the configured bounds for the bucket or <see
        /// cref="double.PositiveInfinity"/> for the catch-all bucket.
        /// </summary>
        public double ExplicitBound { get; }

        /// <summary>
        /// Gets the count of items in the bucket.
        /// </summary>
        public long BucketCount { get; }
    }
}
